require "numru/advanceddcl"

include NumRu::AdvancedDCL
include NMath

n = 30
a = 3.7
r = 0.2

x = Array.new(n)
y = Array.new(n)

#-----------------------------------------------------------------------
(0..(n-1)).each{|i|
  r = a * r * (1.0-r)
  x[i] = i/29.0
  y[i] = r
}

#-----------------------------------------------------------------------
Dev.open("X")

Frame.new
Fig.window=[0.0, 1.0, 0.0, 1.0]
Axis.draw
Plot.draw(x, y)

Dev.close

